.. _cli_jobs_credits:

qbraid jobs get-credits
========================

Get number of qBraid credits remaining.

.. code-block:: bash

    qbraid jobs get-credits


Examples
---------

.. code-block:: console

    $ qbraid jobs get-credits
    You have 1000 remaining qBraid credits.

.. seealso::

    - :ref:`qbraid jobs enable<cli_jobs_enable>`